CacheService class

Constructors

CacheService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBool(String key) → Future<bool?>
getMap(String key) → Future<Map?>
getString(String key) → Future<String?>
putBool(String key, bool value) → Future<bool>?
putMap(String key, Map value) → Future<bool>?
putString(String key, String value) → Future<bool>?
remove(String key) → Future<bool>?
setup() → Future