ResponseData class

Constructors

ResponseData({int? code, String? message, dynamic data})
ResponseData.fromJson(Map json)

Properties

code → int?
final
data → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getTypedData<T>(T? creator(Map? map)) → T?
getTypedList<T>(T? creator(Map? map)) → List<T>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tojson() → Map
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

toInt(dynamic data) → int?
toList<T>(List? mapList, T? creator(Map? map)) → List<T>?